from _typeshed import Incomplete

from stripe import api_requestor as api_requestor
from stripe.api_resources.abstract import DeletableAPIResource as DeletableAPIResource

class EphemeralKey(DeletableAPIResource):
    OBJECT_NAME: str
    @classmethod
    def create(
        cls,
        api_key: Incomplete | None = ...,
        idempotency_key: str | None = ...,
        stripe_version: Incomplete | None = ...,
        stripe_account: Incomplete | None = ...,
        **params,
    ): ...



from _typeshed import Incomplete
from typing import NoReturn

from stripe.api_resources.abstract import (
    DeletableAPIResource as DeletableAPIResource,
    UpdateableAPIResource as UpdateableAPIResource,
)
from stripe.api_resources.customer import Customer as Customer

class AlipayAccount(DeletableAPIResource, UpdateableAPIResource):
    OBJECT_NAME: str
    def instance_url(self): ...
    @classmethod
    def modify(cls, customer, id, **params): ...
    @classmethod
    def retrieve(
        cls,
        id,
        api_key: Incomplete | None = ...,
        stripe_version: Incomplete | None = ...,
        stripe_account: Incomplete | None = ...,
        **params,
    ) -> NoReturn: ...
